@@ -8,7 +8,6 @@ import sys
 from contextlib import contextmanager
 from functools import partial
 
-import coverage
 import pytest
 import six
 
@@ -130,9 +129,38 @@ def ensure_py_info_cache_empty(session_app_data):
     PythonInfo.clear_cache(session_app_data)
 
 
-@pytest.fixture(autouse=True)
-def ignore_global_config(tmp_path, monkeypatch):
-    monkeypatch.setenv(ensure_str("VIRTUALENV_CONFIG_FILE"), str(tmp_path / "this-should-never-exist"))
+@contextmanager
+def change_os_environ(key, value):
+    env_var = key
+    previous = os.environ[env_var] if env_var in os.environ else None
+    os.environ[env_var] = value
+    try:
+        yield
+    finally:
+        if previous is not None:
+            os.environ[env_var] = previous
+
+
+@pytest.fixture(autouse=True, scope="session")
+def ignore_global_config(tmp_path_factory):
+    filename = str(tmp_path_factory.mktemp("folder") / "virtualenv-test-suite.ini")
+    with change_os_environ(ensure_str("VIRTUALENV_CONFIG_FILE"), filename):
+        yield
+
+
+@pytest.fixture(autouse=True, scope="session")
+def pip_cert(tmp_path_factory):
+    # workaround for https://github.com/pypa/pip/issues/8984 - if the certificate is explicitly set no error can happen
+    key = ensure_str("PIP_CERT")
+    if key in os.environ:
+        return
+    cert = tmp_path_factory.mktemp("folder") / "cert"
+    import pkgutil
+
+    cert_data = pkgutil.get_data("pip._vendor.certifi", "cacert.pem")
+    cert.write_bytes(cert_data)
+    with change_os_environ(key, str(cert)):
+        yield
 
 
 @pytest.fixture(autouse=True)
@@ -196,8 +224,8 @@ def coverage_env(monkeypatch, link, request):
         # we inject right after creation, we cannot collect coverage on site.py - used for helper scripts, such as debug
         from virtualenv import run
 
-        def _session_via_cli(args, options, setup_logging):
-            session = prev_run(args, options, setup_logging)
+        def _session_via_cli(args, options, setup_logging, env=None):
+            session = prev_run(args, options, setup_logging, env)
             old_run = session.creator.run
 
             def create_run():
@@ -236,28 +264,31 @@ def no_coverage():
     pass
 
 
-class EnableCoverage(object):
-    _COV_FILE = Path(coverage.__file__)
-    _ROOT_COV_FILES_AND_FOLDERS = [i for i in _COV_FILE.parents[1].iterdir() if i.name.startswith("coverage")]
+if COVERAGE_RUN:
+    import coverage
 
-    def __init__(self, link):
-        self.link = link
-        self.targets = []
+    class EnableCoverage(object):
+        _COV_FILE = Path(coverage.__file__)
+        _ROOT_COV_FILES_AND_FOLDERS = [i for i in _COV_FILE.parents[1].iterdir() if i.name.startswith("coverage")]
 
-    def __enter__(self, creator):
-        site_packages = creator.purelib
-        for entry in self._ROOT_COV_FILES_AND_FOLDERS:
-            target = site_packages / entry.name
-            if not target.exists():
-                clean = self.link(entry, target)
-                self.targets.append((target, clean))
-        return self
+        def __init__(self, link):
+            self.link = link
+            self.targets = []
 
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        for target, clean in self.targets:
-            if target.exists():
-                clean()
-        assert self._COV_FILE.exists()
+        def __enter__(self, creator):
+            site_packages = creator.purelib
+            for entry in self._ROOT_COV_FILES_AND_FOLDERS:
+                target = site_packages / entry.name
+                if not target.exists():
+                    clean = self.link(entry, target)
+                    self.targets.append((target, clean))
+            return self
+
+        def __exit__(self, exc_type, exc_val, exc_tb):
+            for target, clean in self.targets:
+                if target.exists():
+                    clean()
+            assert self._COV_FILE.exists()
 
 
 @pytest.fixture(scope="session")
@@ -303,7 +334,8 @@ def current_fastest(current_creators):
 
 @pytest.fixture(scope="session")
 def session_app_data(tmp_path_factory):
-    app_data = AppDataDiskFolder(folder=str(tmp_path_factory.mktemp("session-app-data")))
+    temp_folder = tmp_path_factory.mktemp("session-app-data")
+    app_data = AppDataDiskFolder(folder=str(temp_folder))
     with change_env_var(str("VIRTUALENV_OVERRIDE_APP_DATA"), str(app_data.lock.path)):
         yield app_data
 
@@ -336,7 +368,7 @@ def temp_app_data(monkeypatch, tmp_path):
 @pytest.fixture(scope="session")
 def cross_python(is_inside_ci, session_app_data):
     spec = str(2 if sys.version_info[0] == 3 else 3)
-    interpreter = get_interpreter(spec, session_app_data)
+    interpreter = get_interpreter(spec, [], session_app_data)
     if interpreter is None:
         msg = "could not find {}".format(spec)
         if is_inside_ci:
